bayespy.nodes.Take
==================

.. currentmodule:: bayespy.nodes

.. autoclass:: Take

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Take.__init__
      ~Take.add_plate_axis
      ~Take.broadcasting_multiplier
      ~Take.delete
      ~Take.get_mask
      ~Take.get_moments
      ~Take.get_shape
      ~Take.has_plotter
      ~Take.lower_bound_contribution
      ~Take.move_plates
      ~Take.plot
      ~Take.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Take.plates
      ~Take.plates_multiplier
   
   